package com.caimei.controller;

import com.caimei.model.ResponseJson;
import com.caimei.model.dto.ProductSaveDto;
import com.caimei.model.vo.ProductFormVo;
import com.caimei.model.vo.ProductListVo;
import com.caimei.service.AuthProductService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import java.io.IOException;
import java.util.Map;

/**
 * 授权商品API
 * @author Aslee
 * @date 2021/5/17
 */
@Api(tags = "授权商品API")
@Slf4j
@RestController
@RequiredArgsConstructor
@RequestMapping("/auth/product")
public class AuthProductApi {

    private final AuthProductService authProductService;

    /**
     * 授权商品列表
     */
    @ApiOperation("授权商品列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "authId", required = true, value = "授权id"),
            @ApiImplicitParam(name = "productName", required = false, value = "商品名称"),
            @ApiImplicitParam(name = "snCode", required = false, value = "商品SN码"),
            @ApiImplicitParam(name = "pageNum", required = false, value = "第几页"),
            @ApiImplicitParam(name = "pageSize", required = false, value = "一页多少条")
    })
    @GetMapping("/list")
    public ResponseJson<PageInfo<ProductListVo>> getProductList(Integer authId, String productName, String snCode,
                                                                    @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                                                    @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize) {
        return authProductService.getProductList(authId, productName, snCode, pageNum, pageSize);
    }


    /**
     * 更新授权商品状态
     */
    @ApiOperation("更新授权商品状态")
    @ApiImplicitParam(name = "params", value = "productId:授权商品id;status:上架状态:0下架 1上架", required = true)
    @PostMapping("/update/status")
    public ResponseJson updateProductStatus(@RequestBody Map<String,Integer> params) {
        Integer productId = params.get("productId");
        Integer status = params.get("status");
        return authProductService.updateProductStatus(productId, status);
    }

    /**
     * 删除授权商品
     */
    @ApiOperation("删除授权商品")
    @ApiImplicitParam(name = "params", value = "productId:授权商品id", required = true)
    @PostMapping("/delete")
    public ResponseJson deleteProduct(@RequestBody Map<String,Integer> params) {
        Integer productId = params.get("productId");
        return authProductService.deleteProduct(productId);
    }

    /**
     * 添加/编辑授权商品
     * @param productSaveDto {
     *                   productId              授权商品id
     *                   authId                 授权id
     *                   brandId                品牌id
     *                   productName            商品名称
     *                   snCode                 商品SN码
     *                   productImage           商品图片
     *                   certificateImage       授权牌照
     *                   status                 上架状态：0下架，1上架
     *                   createBy               创建人id
     *                   paramList              商品参数列表
     * }
     */
    @ApiOperation("添加/编辑授权商品")
    @PostMapping("/save")
    public ResponseJson saveProduct(@RequestBody ProductSaveDto productSaveDto) throws IOException {
        return authProductService.saveProduct(productSaveDto);
    }

    /**
     * 获取授权商品回显数据
     *
     * @param productId 授权商品id
     * @return ProductFormVo
     */
    @ApiOperation("授权商品回显数据")
    @ApiImplicitParam(name = "productId", required = true, value = "授权商品id")
    @GetMapping("/form/data")
    public ResponseJson<ProductFormVo> getProductFormData(Integer productId) {
        return authProductService.getProductFormData(productId);
    }

    /**
     * 更新所有商品的水印图片
     */
    @ApiOperation("更新所有商品的水印图片")
    @PostMapping("/update/all/watermark")
    public ResponseJson updateAllWatermark(){
        return authProductService.updateAllWaterMark();
    }
}
